Use Case:  Rename Content
=========================

  Actor

    - Content Creator

  Overview

    The ID which an author assigns to a piece of content at
    creation time[1] may laterturn out to be inappropriate.

  Assumptions

    - Content Creator has logged into the CMF (see "Login to the
      Site":LoginAsMember).

  Procedure

    1. Navigate to the folder containing the piece of content which
       you would like to rename.

       To retrieve a list of the content you have authored,
       see "View personally authored content":ViewMyContent.

    2. In the "Folder contents" view of the folder, check the box next to
       the content object(s) which you would like to rename.

    3. Click the "Rename" button.

    4. The system will display a form listing each selected content object,
       with input fields for the new ID for each.  Supply new IDs, and click
       the "OK" button.

    5. The content has now been renamed; you will be redirected to the
       folder contents listing with a notification message to that effect.

    6. To undo this action, see "Undo changes to content":UndoChanges.

